'use strict';

module.exports = {
	'Abstract Equality Comparison': 'https://262.ecma-international.org/5.1/#sec-11.9.3',
	'Abstract Relational Comparison': 'https://262.ecma-international.org/5.1/#sec-11.8.5',
	'Strict Equality Comparison': 'https://262.ecma-international.org/5.1/#sec-11.9.6',
	abs: 'http://262.ecma-international.org/5.1/#sec-5.2',
	Canonicalize: 'https://262.ecma-international.org/5.1/#sec-15.10.2.8',
	CheckObjectCoercible: 'https://262.ecma-international.org/5.1/#sec-9.10',
	DateFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.5',
	Day: 'https://262.ecma-international.org/5.1/#sec-15.9.1.2',
	DayFromYear: 'https://262.ecma-international.org/5.1/#sec-15.9.1.3',
	DaysInYear: 'https://262.ecma-international.org/5.1/#sec-15.9.1.3',
	DayWithinYear: 'https://262.ecma-international.org/5.1/#sec-15.9.1.4',
	floor: 'http://262.ecma-international.org/5.1/#sec-5.2',
	FromPropertyDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10.4',
	HourFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.10',
	InLeapYear: 'https://262.ecma-international.org/5.1/#sec-15.9.1.3',
	IsAccessorDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10.1',
	IsCallable: 'https://262.ecma-international.org/5.1/#sec-9.11',
	IsDataDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10.2',
	IsGenericDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10.3',
	IsPropertyDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10',
	MakeDate: 'https://262.ecma-international.org/5.1/#sec-15.9.1.13',
	MakeDay: 'https://262.ecma-international.org/5.1/#sec-15.9.1.12',
	MakeTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.11',
	MinFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.10',
	modulo: 'https://262.ecma-international.org/5.1/#sec-5.2',
	MonthFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.4',
	msFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.10',
	SameValue: 'https://262.ecma-international.org/5.1/#sec-9.12',
	SecFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.10',
	SplitMatch: 'https://262.ecma-international.org/5.1/#sec-15.5.4.14',
	TimeClip: 'https://262.ecma-international.org/5.1/#sec-15.9.1.14',
	TimeFromYear: 'https://262.ecma-international.org/5.1/#sec-15.9.1.3',
	TimeWithinDay: 'https://262.ecma-international.org/5.1/#sec-15.9.1.2',
	ToBoolean: 'https://262.ecma-international.org/5.1/#sec-9.2',
	ToInt32: 'https://262.ecma-international.org/5.1/#sec-9.5',
	ToInteger: 'https://262.ecma-international.org/5.1/#sec-9.4',
	ToNumber: 'https://262.ecma-international.org/5.1/#sec-9.3',
	ToObject: 'https://262.ecma-international.org/5.1/#sec-9.9',
	ToPrimitive: 'https://262.ecma-international.org/5.1/#sec-9.1',
	ToPropertyDescriptor: 'https://262.ecma-international.org/5.1/#sec-8.10.5',
	ToString: 'https://262.ecma-international.org/5.1/#sec-9.8',
	ToUint16: 'https://262.ecma-international.org/5.1/#sec-9.7',
	ToUint32: 'https://262.ecma-international.org/5.1/#sec-9.6',
	Type: 'https://262.ecma-international.org/5.1/#sec-8',
	WeekDay: 'https://262.ecma-international.org/5.1/#sec-15.9.1.6',
	YearFromTime: 'https://262.ecma-international.org/5.1/#sec-15.9.1.3'
};
