'use strict';

// https://262.ecma-international.org/15.0/#sec-isunclampedintegerelementtype

module.exports = function IsUnclampedIntegerElementType(type) {
	return type === 'INT8'
		|| type === 'UINT8'
		|| type === 'INT16'
		|| type === 'UINT16'
		|| type === 'INT32'
		|| type === 'UINT32';
};
