'use strict';

var CompletionRecord = require('./CompletionRecord');

// https://tc39.es/ecma262/#sec-returncompletion

module.exports = function ReturnCompletion(value) {
	return new CompletionRecord('return', value);
};
